# sLOUT by Sidpatchy
Sidpatchy's Library of Useful Things originally written for Sidpatchy's Discord Bot Tools... it is used a large amount of my projects so it has become its own thing.

Installing:
1. `git clone https://github.com/Sidpatchy/sLOUT.git`
2. `cd sLOUT`
3. `pip install .`